package Google::Api::Common;

use strict;
use warnings;

use Protobuf;
use Google::Api::Visibility;
use Google::Api::Http;
use Google::Api::Resource;
use Google::Api::Log;
use Google::Api::Monitoring;
use Google::Api::Label;
use Google::Api::Metric;
use Google::Api::Service;
use Google::Api::Httpbody;
use Google::Api::Control;
use Google::Api::Annotations;
use Google::Api::Documentation;
use Google::Api::Consumer;
use Google::Api::LaunchStage;
use Google::Api::Endpoint;
use Google::Api::Backend;
use Google::Api::Routing;
use Google::Api::Distribution;
use Google::Api::Context;
use Google::Api::Auth;
use Google::Api::Quota;
use Google::Api::SystemParameter;
use Google::Api::FieldBehavior;
use Google::Api::SourceInfo;
use Google::Api::Client;
use Google::Api::MonitoredResource;
use Google::Api::Policy;
use Google::Api::ErrorReason;
use Google::Api::ConfigChange;
use Google::Api::Billing;
use Google::Api::Usage;
use Google::Api::FieldInfo;
use Google::Api::Logging;
use Google::Api::Inclusion;
use Google::Type::Latlng;
use Google::Type::PhoneNumber;
use Google::Type::Quaternion;
use Google::Type::Datetime;
use Google::Type::Date;
use Google::Type::Decimal;
use Google::Type::Month;
use Google::Type::Expr;
use Google::Type::Fraction;
use Google::Type::CalendarPeriod;
use Google::Type::Interval;
use Google::Type::Timeofday;
use Google::Type::Color;
use Google::Type::Money;
use Google::Type::PostalAddress;
use Google::Type::Dayofweek;
use Google::Type::LocalizedText;
use Google::Cloud::REST::Client;

our $VERSION = '0.02';
1; # End of Google::Api::Common

__END__

=head1 NAME

Google::Api::Common - Auto-generated Protocol Buffers schema container

=head1 DESCRIPTION

This is an auto-generated Protocol Buffers schema container module for Google Cloud Services.

=head1 LICENSE

Apache License 2.0

=cut
